@@ -1091,10 +1091,11 @@ sub save_preferences {
   foreach my $item (keys %$form) {
     $myconfig->{$item} = $form->{$item};
   }
-  
+
   $myconfig->{password} = $form->{new_password} if ($form->{old_password} ne $form->{new_password});
 
   $myconfig->save_member($memberfile, $userspath);
+  $form->{sessioncookie} = $myconfig->{sessioncookie};
 
   1;
 
@@ -1104,7 +1105,7 @@ sub save_preferences {
 sub save_defaults {
   my ($self, $myconfig, $form) = @_;
 
-  for (qw(inventory_accno income_accno expense_accno fxgain_accno fxloss_accno)) { ($form->{$_}) = split /--/, $form->{$_} }
+  for (qw(IC IC_income IC_expense FX_gain FX_loss)) { ($form->{$_}) = split /--/, $form->{$_} }
   
   my @a;
   $form->{curr} =~ s/ //g;
@@ -1118,19 +1119,19 @@ sub save_defaults {
   my $query = qq|UPDATE defaults SET
                  inventory_accno_id = 
 		     (SELECT id FROM chart
-		                WHERE accno = '$form->{inventory_accno}'),
+		                WHERE accno = '$form->{IC}'),
                  income_accno_id =
 		     (SELECT id FROM chart
-		                WHERE accno = '$form->{income_accno}'),
+		                WHERE accno = '$form->{IC_income}'),
 	         expense_accno_id =
 		     (SELECT id FROM chart
-		                WHERE accno = '$form->{expense_accno}'),
+		                WHERE accno = '$form->{IC_expense}'),
 	         fxgain_accno_id =
 		     (SELECT id FROM chart
-		                WHERE accno = '$form->{fxgain_accno}'),
+		                WHERE accno = '$form->{FX_gain}'),
 	         fxloss_accno_id =
 		     (SELECT id FROM chart
-		                WHERE accno = '$form->{fxloss_accno}'),
+		                WHERE accno = '$form->{FX_loss}'),
 	         glnumber = '$form->{glnumber}',
 	         sinumber = '$form->{sinumber}',
 		 vinumber = '$form->{vinumber}',
@@ -1142,21 +1143,13 @@ sub save_defaults {
 		 employeenumber = '$form->{employeenumber}',
 		 customernumber = '$form->{customernumber}',
 		 vendornumber = '$form->{vendornumber}',
+		 projectnumber = '$form->{projectnumber}',
 		 yearend = '$form->{yearend}',
 		 curr = '$form->{curr}',
 		 weightunit = |.$dbh->quote($form->{weightunit}).qq|,
 		 businessnumber = |.$dbh->quote($form->{businessnumber});
   $dbh->do($query) || $form->dberror($query);
 
-  foreach my $item (split / /, $form->{taxaccounts}) {
-    $form->{$item} = $form->parse_amount($myconfig, $form->{$item}) / 100;
-    $query = qq|UPDATE tax
-		SET rate = $form->{$item},
-		taxnumber = |.$dbh->quote($form->{"taxnumber_$item"}).qq|
-		WHERE chart_id = $item|;
-    $dbh->do($query) || $form->dberror($query);
-  }
-
   my $rc = $dbh->commit;
   $dbh->disconnect;
 
@@ -1176,14 +1169,16 @@ sub defaultaccounts {
   my $sth = $dbh->prepare($query);
   $sth->execute || $form->dberror($query);
   
-  $form->{defaults} = $sth->fetchrow_hashref(NAME_lc);
-  $form->{defaults}{IC_inventory} = $form->{defaults}{inventory_accno_id};
-  $form->{defaults}{IC_income} = $form->{defaults}{income_accno_id};
-  $form->{defaults}{IC_sale} = $form->{defaults}{income_accno_id};
-  $form->{defaults}{IC_expense} = $form->{defaults}{expense_accno_id};
-  $form->{defaults}{IC_cogs} = $form->{defaults}{expense_accno_id};
-  $form->{defaults}{FX_gain} = $form->{defaults}{fxgain_accno_id};
-  $form->{defaults}{FX_loss} = $form->{defaults}{fxloss_accno_id};
+  my $ref = $sth->fetchrow_hashref(NAME_lc);
+  for (keys %$ref) { $form->{$_} = $ref->{$_} }
+  
+  $form->{defaults}{IC} = $form->{inventory_accno_id};
+  $form->{defaults}{IC_income} = $form->{income_accno_id};
+  $form->{defaults}{IC_sale} = $form->{income_accno_id};
+  $form->{defaults}{IC_expense} = $form->{expense_accno_id};
+  $form->{defaults}{IC_cogs} = $form->{expense_accno_id};
+  $form->{defaults}{FX_gain} = $form->{fxgain_accno_id};
+  $form->{defaults}{FX_loss} = $form->{fxloss_accno_id};
   
   $sth->finish;
 
@@ -1195,7 +1190,7 @@ sub defaultaccounts {
   $sth->execute || $form->dberror($query);
 
   my $nkey;
-  while (my $ref = $sth->fetchrow_hashref(NAME_lc)) {
+  while ($ref = $sth->fetchrow_hashref(NAME_lc)) {
     foreach my $key (split(/:/, $ref->{link})) {
       if ($key =~ /IC/) {
 	$nkey = $key;
@@ -1205,7 +1200,7 @@ sub defaultaccounts {
 	if ($key =~ /sale/) {
 	  $nkey = "IC_income";
 	}
-        %{ $form->{IC}{$nkey}{$ref->{accno}} } = ( id => $ref->{id},
+        %{ $form->{accno}{$nkey}{$ref->{accno}} } = ( id => $ref->{id},
                                         description => $ref->{description} );
       }
     }
@@ -1215,55 +1210,78 @@ sub defaultaccounts {
 
   $query = qq|SELECT id, accno, description
               FROM chart
-	      WHERE category = 'I'
+	      WHERE (category = 'I' OR category = 'E')
 	      AND charttype = 'A'
               ORDER BY accno|;
   $sth = $dbh->prepare($query);
   $sth->execute || $form->dberror($query);
 
   while (my $ref = $sth->fetchrow_hashref(NAME_lc)) {
-    %{ $form->{IC}{FX_gain}{$ref->{accno}} } = ( id => $ref->{id},
+    %{ $form->{accno}{FX_gain}{$ref->{accno}} } = ( id => $ref->{id},
+                                      description => $ref->{description} );
+    %{ $form->{accno}{FX_loss}{$ref->{accno}} } = ( id => $ref->{id},
                                       description => $ref->{description} );
   }
   $sth->finish;
 
-  $query = qq|SELECT id, accno, description
-              FROM chart
-	      WHERE category = 'E'
-	      AND charttype = 'A'
-              ORDER BY accno|;
-  $sth = $dbh->prepare($query);
-  $sth->execute || $form->dberror($query);
-
-  while (my $ref = $sth->fetchrow_hashref(NAME_lc)) {
-    %{ $form->{IC}{FX_loss}{$ref->{accno}} } = ( id => $ref->{id},
-                                      description => $ref->{description} );
-  }
-  $sth->finish;
-
-
-  # now get the tax rates and numbers
-  $query = qq|SELECT chart.id, chart.accno, chart.description,
-              tax.rate * 100 AS rate, tax.taxnumber
-              FROM chart, tax
-	      WHERE chart.id = tax.chart_id|;
-
-  $sth = $dbh->prepare($query);
-  $sth->execute || $form->dberror($query);
-
-  while (my $ref = $sth->fetchrow_hashref(NAME_lc)) {
-    $form->{taxrates}{$ref->{accno}}{id} = $ref->{id};
-    $form->{taxrates}{$ref->{accno}}{description} = $ref->{description};
-    $form->{taxrates}{$ref->{accno}}{taxnumber} = $ref->{taxnumber} if $ref->{taxnumber};
-    $form->{taxrates}{$ref->{accno}}{rate} = $ref->{rate} if $ref->{rate};
-  }
-
-  $sth->finish;
   $dbh->disconnect;
   
 }
 
 
+sub taxes {
+  my ($self, $myconfig, $form) = @_;
+  
+  # connect to database
+  my $dbh = $form->dbconnect($myconfig);
+  
+  my $query = qq|SELECT c.id, c.accno, c.description,
+              t.rate * 100 AS rate, t.taxnumber, t.validto
+              FROM chart c
+	      JOIN tax t ON (c.id = t.chart_id)
+	      ORDER BY 3, 6|;
+
+  my $sth = $dbh->prepare($query);
+  $sth->execute || $form->dberror($query);
+
+  while (my $ref = $sth->fetchrow_hashref(NAME_lc)) {
+    push @{ $form->{taxrates} }, $ref;
+  }
+  $sth->finish;
+
+  $dbh->disconnect;
+  
+}
+
+
+sub save_taxes {
+  my ($self, $myconfig, $form) = @_;
+
+  # connect to database
+  my $dbh = $form->dbconnect_noauto($myconfig);
+
+  my $query = qq|DELETE FROM tax|;
+  $dbh->do($query) || $form->dberror($query);
+
+  foreach my $item (split / /, $form->{taxaccounts}) {
+    my ($chart_id, $i) = split /_/, $item;
+    my $rate = $form->parse_amount($myconfig, $form->{"taxrate_$i"}) / 100;
+    $query = qq|INSERT INTO tax (chart_id, rate, taxnumber, validto)
+                VALUES ($chart_id, $rate, |
+		.$dbh->quote($form->{"taxnumber_$i"}).qq|, |
+		.$form->dbquote($form->{"validto_$i"}, SQL_DATE)
+		.qq|)|;
+    $dbh->do($query) || $form->dberror($query);
+  }
+
+  my $rc = $dbh->commit;
+  $dbh->disconnect;
+
+  $rc;
+ 
+}
+
+
 sub backup {
   my ($self, $myconfig, $form, $userspath, $gzip) = @_;
   
@@ -1277,7 +1295,7 @@ sub backup {
   $t[4] = substr("0$t[4]", -2);
 
   my $boundary = time;
-  my $tmpfile = "$userspath/$boundary.$myconfig->{dbname}-$form->{dbversion}-$t[5]$t[4]$t[3]";
+  my $tmpfile = "$userspath/$boundary.$myconfig->{dbname}-$form->{dbversion}-$t[5]$t[4]$t[3].sql";
   my $out = $form->{OUT};
   $form->{OUT} = ">$tmpfile";
 
@@ -1428,6 +1446,32 @@ sub backup {
     }
   }
   
+  # create sequences
+  foreach $item (@sequences) {
+    if ($myconfig->{dbdriver} eq 'DB2') {
+      $query = qq|SELECT NEXTVAL FOR $item FROM sysibm.sysdummy1|;
+    } else {
+      $query = qq|SELECT last_value FROM $item|;
+    }
+    
+    my ($id) = $dbh->selectrow_array($query);
+  
+    if ($myconfig->{dbdriver} eq 'DB2') {
+      print OUT qq|DROP SEQUENCE $item RESTRICT
+CREATE SEQUENCE $item AS INTEGER START WITH $id INCREMENT BY 1 MAXVALUE 2147483647 MINVALUE 1 CACHE 5;\n|;
+    } else {
+      if ($myconfig->{dbdriver} eq 'Pg') {
+	print OUT qq|CREATE SEQUENCE $item;
+SELECT SETVAL('$item', $id, FALSE);\n|;
+      } else {
+	print OUT qq|DROP SEQUENCE $item
+CREATE SEQUENCE $item START $id;\n|;
+      }
+    }
+  }
+ 
+  print OUT "--\n";
+
   # add schema
   print OUT @schema;
   print OUT "\n";
@@ -1465,30 +1509,6 @@ $myconfig->{dboptions};
     $sth->finish;
   }
 
- 
-  my $restrict = ($myconfig->{dbdriver} eq 'DB2') ? "RESTRICT" : "";
- 
-  # create sequences and triggers
-  foreach $item (@sequences) {
-    if ($myconfig->{dbdriver} eq 'DB2') {
-      $query = qq|SELECT NEXTVAL FOR $item FROM sysibm.sysdummy1|;
-    } else {
-      $query = qq|SELECT last_value FROM $item|;
-    }
-    
-    my ($id) = $dbh->selectrow_array($query);
-    $id++;
-  
-    print OUT qq|--
-DROP SEQUENCE $item $restrict;\n|;
-    
-    if ($myconfig->{dbdriver} eq 'DB2') {
-      print OUT qq|CREATE SEQUENCE $item AS INTEGER START WITH $id INCREMENT BY 1 MAXVALUE 2147483647 MINVALUE 1 CACHE 5;\n|;
-    } else {
-      print OUT qq|CREATE SEQUENCE $item START $id;\n|;
-    }
-  }
-
   print OUT "--\n";
   
   # functions
@@ -1529,7 +1549,7 @@ DROP SEQUENCE $item $restrict;\n|;
 
     $mail->{to} = qq|"$myconfig->{name}" <$myconfig->{email}>|;
     $mail->{from} = qq|"$myconfig->{name}" <$myconfig->{email}>|;
-    $mail->{subject} = "SQL-Ledger Backup / $myconfig->{dbname}-$form->{dbversion}-$t[5]$t[4]$t[3]$suffix";
+    $mail->{subject} = "SQL-Ledger Backup / $myconfig->{dbname}-$form->{dbversion}-$t[5]$t[4]$t[3].sql$suffix";
     @{ $mail->{attachments} } = ($tmpfile);
     $mail->{version} = $form->{version};
     $mail->{fileid} = "$boundary.";
@@ -1546,10 +1566,12 @@ DROP SEQUENCE $item $restrict;\n|;
     open(OUT, ">-") or $form->error("STDOUT : $!");
    
     print OUT qq|Content-Type: application/file;
-Content-Disposition: attachment; filename="$myconfig->{dbname}-$form->{dbversion}-$t[5]$t[4]$t[3]$suffix"
+Content-Disposition: attachment; filename="$myconfig->{dbname}-$form->{dbversion}-$t[5]$t[4]$t[3].sql$suffix"
 
 |;
-
+    binmode(IN);
+    binmode(OUT);
+    
     while (<IN>) {
       print OUT $_;
     }
@@ -1582,23 +1604,15 @@ sub closebooks {
   my ($self, $myconfig, $form) = @_;
 
   my $dbh = $form->dbconnect_noauto($myconfig);
+  my $query = qq|UPDATE defaults SET|;
 
   if ($form->{revtrans}) {
-    
-    $query = qq|UPDATE defaults SET closedto = NULL,
-				    revtrans = '1'|;
+    $query .= qq| revtrans = '1'|;
   } else {
-    if ($form->{closedto}) {
-      
-      $query = qq|UPDATE defaults SET closedto = '$form->{closedto}',
-				      revtrans = '0'|;
-    } else {
-      
-      $query = qq|UPDATE defaults SET closedto = NULL,
-				      revtrans = '0'|;
-    }
+    $query .= qq| revtrans = '0'|;
   }
-
+  $query .= qq|, closedto = |.$form->dbquote($form->{closedto}, SQL_DATE);
+  
   if ($form->{audittrail}) {
     $query .= qq|, audittrail = '1'|;
   } else {
@@ -1613,8 +1627,7 @@ sub closebooks {
                 WHERE transdate < '$form->{removeaudittrail}'|;
     $dbh->do($query) || $form->dberror($query);
   }
-		
-  
+
   $dbh->commit;
   $dbh->disconnect;
   
@@ -1656,8 +1669,8 @@ sub post_yearend {
   my $dbh = $form->dbconnect_noauto($myconfig);
 
   my $query;
-  my $uid = time;
-  $uid .= $$;
+  my $uid = localtime;
+  $uid .= "$$";
 
   $query = qq|INSERT INTO gl (reference, employee_id)
 	      VALUES ('$uid', (SELECT id FROM employee
