@@ -56,10 +56,8 @@ sub new {
 
   $self->{menubar} = 1 if $self->{path} =~ /lynx/i;
 
-  $self->{version} = "2.6.5";
-  $self->{dbversion} = "2.6.4";
-
-  $self->{debug} = 1;
+  $self->{version} = "2.6.22";
+  $self->{dbversion} = "2.6.12";
 
   bless $self, $type;
   
@@ -86,7 +84,7 @@ sub escape {
 
   # for Apache 2 we escape strings twice
   if (($ENV{SERVER_SIGNATURE} =~ /Apache\/2\.(\d+)\.(\d+)/) && !$beenthere) {
-    $str = $self->escape($str, 1) if $2 < 44;
+    $str = $self->escape($str, 1) if $1 == 0 && $2 < 44;
   }
 	    
   $str =~ s/([^a-zA-Z0-9_.-])/sprintf("%%%02x", ord($1))/ge;
@@ -157,7 +155,7 @@ sub error {
     delete $self->{pre};
 
     if (!$self->{header}) {
-      $self->header;
+      $self->header(0,1);
     }
 
     print qq|<body><h2 class=error>Error!</h2>
@@ -187,10 +185,9 @@ sub info {
     delete $self->{pre};
 
     if (!$self->{header}) {
-      $self->header;
+      $self->header(0,1);
       print qq|
       <body>|;
-      $self->{header} = 1;
     }
 
     print "<b>$msg</b>";
@@ -237,7 +234,7 @@ sub isblank {
   
 
 sub header {
-  my ($self, $init) = @_;
+  my ($self, $endsession, $nocookie) = @_;
 
   return if $self->{header};
 
@@ -251,7 +248,8 @@ sub header {
     }
 
     if ($self->{favicon} && (-f "$self->{favicon}")) {
-      $favicon = qq|<LINK REL="shortcut icon" HREF="$self->{favicon}" TYPE="image/x-icon">
+      $favicon = qq|<LINK REL="icon" HREF="$self->{favicon}" TYPE="image/x-icon">
+<LINK REL="shortcut icon" HREF="$self->{favicon}" TYPE="image/x-icon">
   |;
     }
 
@@ -262,12 +260,13 @@ sub header {
 
     $self->{titlebar} = ($self->{title}) ? "$self->{title} - $self->{titlebar}" : $self->{titlebar};
 
-    $self->set_cookie($init);
+    $self->set_cookie($endsession) unless $nocookie;
 
     print qq|Content-Type: text/html
 
 <head>
   <title>$self->{titlebar}</title>
+  <META NAME="robots" CONTENT="noindex,nofollow" />
   $favicon
   $stylesheet
   $charset
@@ -283,25 +282,29 @@ $self->{pre}
 
 
 sub set_cookie {
-  my ($self, $init) = @_;
+  my ($self, $endsession) = @_;
 
-  $self->{timeout} = ($self->{timeout} > 0) ? $self->{timeout} : 3600;
-  my $t = ($self->{endsession}) ? time : time + $self->{timeout};
+  $self->{timeout} ||= 31557600;
+  my $t = ($endsession) ? time : time + $self->{timeout};
+  my $login = ($self->{"root login"}) ? "root login" : $self->{login};
   
   if ($ENV{HTTP_USER_AGENT}) {
-
     my @d = split / +/, scalar gmtime($t);
     my $today = "$d[0], $d[2]-$d[1]-$d[4] $d[3] GMT";
 
-    if ($init) {
-      $self->{sessionid} = time;
+    if ($login) {
+      if ($self->{sessioncookie}) {
+	print qq|Set-Cookie: SL-${login}=$self->{sessioncookie}; expires=$today; path=/;\n|;
+      } else {
+	print qq|Set-Cookie: SL-${login}=; expires=$today; path=/;\n|;
+      }
     }
-    print qq|Set-Cookie: SQL-Ledger-$self->{login}=$self->{sessionid}; expires=$today; path=/;\n| if $self->{login};
+      
   }
 
 }
 
- 
+
 sub redirect {
   my ($self, $msg) = @_;
 
@@ -496,6 +499,9 @@ sub parse_template {
   my $subdir = "";
   my $err = "";
 
+  my %include = ();
+  my $ok;
+
   if ($self->{language_code}) {
     if (-f "$self->{templates}/$self->{language_code}/$self->{IN}") {
       open(IN, "$self->{templates}/$self->{language_code}/$self->{IN}") or $self->error("$self->{IN} : $!");
@@ -540,25 +546,25 @@ sub parse_template {
     $var = $_;
 
     # detect pagebreak block and its parameters
-    if (/\s*<%pagebreak ([0-9]+) ([0-9]+) ([0-9]+)%>/) {
+    if (/<%pagebreak ([0-9]+) ([0-9]+) ([0-9]+)%>/) {
       $chars_per_line = $1;
       $lines_on_first_page = $2;
       $lines_on_second_page = $3;
       
       while ($_ = shift) {
-        last if (/\s*<%end pagebreak%>/);
+        last if (/<%end pagebreak%>/);
         $pagebreak .= $_;
       }
     }
 
     
-    if (/\s*<%foreach /) {
+    if (/<%foreach /) {
       
       # this one we need for the count
       chomp $var;
-      $var =~ s/\s*<%foreach (.+?)%>/$1/;
+      $var =~ s/.*?<%foreach (.+?)%>/$1/;
       while ($_ = shift) {
-	last if (/\s*<%end $var%>/);
+	last if (/<%end $var%>/);
 
 	# store line in $par
 	$par .= $_;
@@ -574,40 +580,56 @@ sub parse_template {
         # Try to detect whether a manual page break is necessary
         # but only if there was a <%pagebreak ...%> block before
 	
-        if ($chars_per_line && defined $self->{$var}) {
-          my $lines = int(length($self->{description}[$i]) / $chars_per_line + 0.95);
-          my $lpp;
-	  
-          if ($current_page == 1) {
-            $lpp = $lines_on_first_page;
-          } else {
-            $lpp = $lines_on_second_page;
-          }
+	if ($var eq 'number' || $var eq 'part' || $var eq 'service') {
+	  if ($chars_per_line && defined $self->{$var}) {
+	    my $line;
+	    my $lines = 0;
+	    my @d = (description);
+	    push @d, "itemnotes" if $self->{countitemnotes};
+	    
+	    foreach my $item (@d) {
+	      if ($self->{$item}[$i]) {
+		foreach $line (split /\r?\n/, $self->{$item}[$i]) {
+		  $lines++;
+		  $lines += int(length($line) / $chars_per_line);
+		}
+	      }
+	    }
+	      
+	    my $lpp;
+	    
+	    if ($current_page == 1) {
+	      $lpp = $lines_on_first_page;
+	    } else {
+	      $lpp = $lines_on_second_page;
+	    }
 
-          # Yes we need a manual page break
-          if (($current_line + $lines) >= $lpp) {
-            my $pb = $pagebreak;
-	    
-            # replace the special variables <%sumcarriedforward%>
-            # and <%lastpage%>
-	    
-            my $psum = $self->format_amount($myconfig, $sum, 2);
-            $pb =~ s/<%sumcarriedforward%>/$psum/g;
-            $pb =~ s/<%lastpage%>/$current_page/g;
-            
-	    # only "normal" variables are supported here
-            # (no <%if, no <%foreach, no <%include)
-            
-	    $pb =~ s/<%(.+?)%>/$self->{$1}/g;
-            
-	    # page break block is ready to rock
-            print(OUT $pb);
-            $current_page++;
-            $current_line = 1;
-          }
-          $current_line += $lines;
-        }
-        $sum += $self->parse_amount($myconfig, $self->{linetotal}[$i]);
+	    # Yes we need a manual page break
+	    if (($current_line + $lines) > $lpp) {
+	      my $pb = $pagebreak;
+	      
+	      # replace the special variables <%sumcarriedforward%>
+	      # and <%lastpage%>
+	      
+	      my $psum = $self->format_amount($myconfig, $sum, 2);
+	      $pb =~ s/<%sumcarriedforward%>/$psum/g;
+	      $pb =~ s/<%lastpage%>/$current_page/g;
+	      
+	      # only "normal" variables are supported here
+	      # (no <%if, no <%foreach, no <%include)
+	      
+	      $pb =~ s/<%(.+?)%>/$self->{$1}/g;
+	      
+	      # page break block is ready to rock
+	      print(OUT $pb);
+	      $current_page++;
+	      $current_line = 1;
+	      $lines = 0;
+	    }
+	    $current_line += $lines;
+	  }
+	  $sum += $self->parse_amount($myconfig, $self->{linetotal}[$i]);
+	}
 
 	# don't parse par, we need it for each line
 	print OUT $self->format_line($par, $i);
@@ -617,14 +639,14 @@ sub parse_template {
     }
 
     # if not comes before if!
-    if (/\s*<%if not /) {
+    if (/<%if not /) {
       # check if it is not set and display
       chop;
-      s/\s*<%if not (.+?)%>/$1/;
+      s/.*?<%if not (.+?)%>/$1/;
 
       if (! $self->{$_}) {
 	while ($_ = shift) {
-	  last if (/\s*<%end /);
+	  last if (/<%end /);
 
 	  # store line in $par
 	  $par .= $_;
@@ -634,21 +656,27 @@ sub parse_template {
 	
       } else {
 	while ($_ = shift) {
-	  last if (/\s*<%end /);
+	  last if (/<%end /);
 	}
 	next;
       }
     }
  
-    if (/\s*<%if /) {
+    if (/<%if /) {
       # check if it is set and display
       chop;
-      s/\s*<%if (.+?)%>/$1/;
-
-      if ($self->{$_}) {
+      s/.*?<%if (.+?)%>/$1/;
+      
+      if (/\s/) {
+	@a = split;
+	$ok = eval "$self->{$a[0]} $a[1] $a[2]";
+      } else {
+	$ok = $self->{$_};
+      }
+	
+      if ($ok) {
 	while ($_ = shift) {
-	  last if (/\s*<%end /);
-
+	  last if (/<%end /);
 	  # store line in $par
 	  $par .= $_;
 	}
@@ -657,34 +685,34 @@ sub parse_template {
 	
       } else {
 	while ($_ = shift) {
-	  last if (/\s*<%end /);
+	  last if (/<%end /);
 	}
 	next;
       }
     }
    
     # check for <%include filename%>
-    if (/\s*<%include /) {
+    if (/<%include /) {
       
       # get the filename
       chomp $var;
-      $var =~ s/\s*<%include (.+?)%>/$1/;
+      $var =~ s/.*?<%include (.+?)%>/$1/;
 
-      # mangle filename
+      # remove / .. for security reasons
       $var =~ s/(\/|\.\.)//g;
 
-      # prevent the infinite loop!
-      next if ($self->{"$var"});
+      # assume loop after 10 includes of the same file
+      next if ($include{$var} > 10);
 
-      unless (open(INC, "$self->{templates}/$var")) {
+      unless (open(INC, "$self->{templates}/$self->{language_code}/$var")) {
         $err = $!;
 	$self->cleanup;
-	$self->error("$self->{templates}/$var : $err");
+	$self->error("$self->{templates}/$self->{language_code}/$var : $err");
       }
       unshift(@_, <INC>);
       close(INC);
 
-      $self->{"$var"} = 1;
+      $include{$var}++;
 
       next;
     }
@@ -695,6 +723,7 @@ sub parse_template {
 
   close(OUT);
 
+  delete $self->{countitemnotes};
 
   # Convert the tex file to postscript
   if ($self->{format} =~ /(postscript|pdf)/) {
@@ -714,9 +743,15 @@ sub parse_template {
     $self->{errfile} = $self->{tmpfile};
     $self->{errfile} =~ s/tex$/err/;
 
+    my $r = 1;
     if ($self->{format} eq 'postscript') {
 
       system("latex --interaction=nonstopmode $self->{tmpfile} > $self->{errfile}");
+      while ($self->rerun_latex) {
+	system("latex --interaction=nonstopmode $self->{tmpfile} > $self->{errfile}");
+	last if ++$r > 4;
+      }
+	
       $self->{tmpfile} =~ s/tex$/dvi/;
       $self->error($self->cleanup) if ! (-f $self->{tmpfile});
  
@@ -726,6 +761,11 @@ sub parse_template {
     }
     if ($self->{format} eq 'pdf') {
       system("pdflatex --interaction=nonstopmode $self->{tmpfile} > $self->{errfile}");
+      while ($self->rerun_latex) {
+	system("pdflatex --interaction=nonstopmode $self->{tmpfile} > $self->{errfile}");
+	last if ++$r > 4;
+      }
+
       $self->{tmpfile} =~ s/tex$/pdf/;
       $self->error($self->cleanup) if ! (-f $self->{tmpfile});
     }
@@ -873,11 +913,13 @@ sub format_line {
     $str = (defined $i) ? $self->{$var}[$i] : $self->{$var};
     $newstr = $str;
 
+    $self->{countitemnotes} = 1 if $var eq 'itemnotes';
+    
     $var = $1;
     if ($var =~ /^if\s+not\s+/) {
       if ($str) {
 	$var =~ s/if\s+not\s+//;
-	s/<%if\s+not\s+$var%>.*?<%end\s+$var%>//s;
+	s/<%if\s+not\s+$var%>.*?(<%end\s+$var%>|$)//s;
       } else {
 	s/<%$var%>//;
       }
@@ -889,7 +931,7 @@ sub format_line {
 	s/<%$var%>//;
       } else {
 	$var =~ s/if\s+//;
-	s/<%if\s+$var%>.*?<%end\s+$var%>//s;
+	s/<%if\s+$var%>.*?(<%end\s+$var%>|$)//s;
       }
       next;
     }
@@ -986,6 +1028,21 @@ sub cleanup {
 }
 
 
+sub rerun_latex {
+  my $self = shift;
+
+  my $a = 0;
+  if (-f "$self->{errfile}") {
+    open(FH, "$self->{errfile}");
+    $a = grep /(longtable Warning:|Warning:.*?LastPage)/, <FH>;
+    close(FH);
+  }
+
+  $a;
+
+}
+
+
 sub format_string {
   my ($self, @fields) = @_;
 
@@ -1358,7 +1415,8 @@ sub get_name {
   my $name = $self->like(lc $self->{$table});
   my $query = qq|SELECT *
                  FROM $table
-		 WHERE lower(name) LIKE '$name'
+		 WHERE (lower(name) LIKE '$name'
+		        OR ${table}number LIKE '$name')
 		 $where
 		 ORDER BY name|;
 
@@ -1451,11 +1509,52 @@ sub all_vc {
   }
   $sth->finish;
 
+  $self->all_taxaccounts($myconfig, $dbh, $transdate);
+
   $dbh->disconnect if $disconnect;
 
 }
 
 
+sub all_taxaccounts {
+  my ($self, $myconfig, $dbh, $transdate) = @_;
+
+  my $disconnect = ($dbh) ? 0 : 1;
+
+  if (! $dbh) {
+    $dbh = $self->dbconnect($myconfig);
+  }
+  my $sth;
+  my $query;
+  my $where;
+  
+
+  if ($transdate) {
+    $where = qq| AND (t.validto >= '$transdate' OR t.validto IS NULL)|;
+  }
+
+  if ($self->{taxaccounts}) {
+    # rebuild tax rates
+    $query = qq|SELECT t.rate, t.taxnumber 
+                FROM tax t 
+		JOIN chart c ON (c.id = t.chart_id) 
+		WHERE c.accno = ?
+		$where
+		ORDER BY accno, validto|; 
+    $sth = $dbh->prepare($query) || $self->dberror($query);
+
+    foreach my $accno (split / /, $self->{taxaccounts}) {
+      $sth->execute($accno); 
+      ($self->{"${accno}_rate"}, $self->{"${accno}_taxnumber"}) = $sth->fetchrow_array;
+      $sth->finish;
+    }
+  }
+
+  $dbh->disconnect if $disconnect;
+  
+}
+
+ 
 sub all_employees {
   my ($self, $myconfig, $dbh, $transdate, $sales) = @_;
   
@@ -1467,7 +1566,10 @@ sub all_employees {
   if ($transdate) {
     $query .= qq| AND (startdate IS NULL OR startdate <= '$transdate')
                   AND (enddate IS NULL OR enddate >= '$transdate')|;
+  } else {
+    $query .= qq| AND enddate IS NULL|;
   }
+  
   if ($sales) {
     $query .= qq| AND sales = '1'|;
   }
@@ -1658,8 +1760,9 @@ sub create_links {
   }
   $sth->finish;
 
+  my $arap = ($vc eq 'customer') ? 'ar' : 'ap';
+  
   if ($self->{id}) {
-    my $arap = ($vc eq 'customer') ? 'ar' : 'ap';
     
     $query = qq|SELECT a.invnumber, a.transdate,
                 a.${vc}_id, a.datepaid, a.duedate, a.ordnumber,
@@ -1850,7 +1953,11 @@ sub like {
   my ($self, $str) = @_;
   
   if ($str !~ /(%|_)/) {
-    $str = "%$str%";
+    if ($str =~ /(^").*("$)/) {
+      $str =~ s/(^"|"$)//g; 
+    } else { 
+      $str = "%$str%";
+    }
   }
 
   $str =~ s/'/''/g;
@@ -1955,7 +2062,7 @@ sub update_status {
   my $dbh = $self->dbconnect_noauto($myconfig);
 
   my %queued = split / +/, $self->{queued};
-  
+  my $spoolfile = ($queued{$self->{formname}}) ? "'$queued{$self->{formname}}'" : 'NULL';
   my $query = qq|DELETE FROM status
  	         WHERE formname = '$self->{formname}'
 	         AND trans_id = $self->{id}|;
@@ -1966,7 +2073,7 @@ sub update_status {
   
   $query = qq|INSERT INTO status (trans_id, printed, emailed,
 	      spoolfile, formname) VALUES ($self->{id}, '$printed',
-	      '$emailed', '$queued{$self->{formname}}',
+	      '$emailed', $spoolfile,
 	      '$self->{formname}')|;
   $dbh->do($query) || $self->dberror($query);
 
