@@ -83,7 +83,8 @@ sub invoice_details {
               WHERE id = ?|;
   my $pth = $dbh->prepare($query) || $form->dberror($query);
 
-
+  my $sortby;
+  
   # sort items by project and partsgroup
   for $i (1 .. $form->{rowcount} - 1) {
 
@@ -133,12 +134,19 @@ sub invoice_details {
 
     }
 
-    push @sortlist, [ $i, qq|$projectnumber$form->{partsgroup}$inventory_accno_id|, $form->{projectnumber}, $projectnumber_id, $form->{partsgroup} ];
+    $sortby = qq|$projectnumber$form->{partsgroup}|;
+    if ($form->{sortby} ne 'runningnumber') {
+      for (qw(partnumber description bin)) {
+	$sortby .= $form->{"${_}_$i"} if $form->{sortby} eq $_;
+      }
+    }
+
+    push @sortlist, [ $i, qq|$projectnumber$form->{partsgroup}$inventory_accno_id|, $form->{projectnumber}, $projectnumber_id, $form->{partsgroup}, $sortby ];
 
   }
 
   # sort the whole thing by project and group
-  @sortlist = sort { $a->[1] cmp $b->[1] } @sortlist;
+  @sortlist = sort { $a->[5] cmp $b->[5] } @sortlist;
 
   my $runningnumber = 1;
   my $sameitem = "";
@@ -210,7 +218,7 @@ sub invoice_details {
       # listprice
       push(@{ $form->{listprice} }, $form->{"listprice_$i"});
       
-      push(@{ $form->{weight} }, $form->format_amount($myconfig, $form->{"weight_$i"}));
+      push(@{ $form->{weight} }, $form->format_amount($myconfig, $form->{"weight_$i"} * $form->{"qty_$i"}));
 
       my $sellprice = $form->parse_amount($myconfig, $form->{"sellprice_$i"});
       my ($dec) = ($sellprice =~ /\.(\d+)/);
@@ -291,7 +299,7 @@ sub invoice_details {
       }
 
       push(@{ $form->{lineitems} }, { amount => $linetotal, tax => $form->round_amount($tax, 2) });
-      push(@{ $form->{taxrates} }, join /:/, sort { $a <=> $b } @taxrates);
+      push(@{ $form->{taxrates} }, join ' ', sort { $a <=> $b } @taxrates);
       
       if ($form->{"assembly_$i"}) {
 	$form->{stagger} = -1;
@@ -421,6 +429,7 @@ sub invoice_details {
   $form->{decimal} = substr($form->{decimal}, 0, 2);
   $form->{text_decimal} = $c->num2text($form->{decimal} * 1);
   $form->{text_amount} = $c->num2text($whole);
+  $form->{integer_amount} = $whole;
  
   $form->format_string(qw(text_amount text_decimal));
 
@@ -568,6 +577,7 @@ sub post_invoice {
   my $null;
   my $project_id;
   my $exchangerate = 0;
+  my $keepcleared = 0;
   
   %$form->{acc_trans} = ();
 
@@ -590,6 +600,7 @@ sub post_invoice {
   my $pth = $dbh->prepare($query) || $form->dberror($query);
   
   if ($form->{id}) {
+    $keepcleared = 1;
     $query = qq|SELECT id FROM ar
                 WHERE id = $form->{id}|;
 
@@ -603,8 +614,8 @@ sub post_invoice {
     
   }
   
-  my $uid = time;
-  $uid .= $$;
+  my $uid = localtime;
+  $uid .= "$$";
  
   if (! $form->{id}) {
    
@@ -797,13 +808,11 @@ sub post_invoice {
     }
   }
 
-  $form->{datepaid} = $form->{transdate};
-  
   $form->{paid} = 0;
   for $i (1 .. $form->{paidaccounts}) {
     $form->{"paid_$i"} = $form->parse_amount($myconfig, $form->{"paid_$i"});
     $form->{paid} += $form->{"paid_$i"};
-    $form->{datepaid} = $form->{"datepaid_$i"} if ($form->{"datepaid_$i"});
+    $form->{datepaid} = $form->{"datepaid_$i"} if ($form->{"paid_$i"});
   }
   
   # add lineitems + tax
@@ -827,6 +836,7 @@ sub post_invoice {
     $invamount += $diff;
   }
   $fxdiff = $form->round_amount($fxdiff,2);
+  $invnetamount += $fxdiff;
   $invamount += $fxdiff;
 
   if ($form->round_amount($form->{paid} - $fxgrossamount,2) == 0) {
@@ -837,7 +847,6 @@ sub post_invoice {
 
   foreach $ref (sort { $b->{amount} <=> $a->{amount} } @ { $form->{acc_trans}{lineitems} }) {
     $amount = $ref->{amount} + $diff + $fxdiff;
-    $ref->{invoice_id} *= 1;
     $query = qq|INSERT INTO acc_trans (trans_id, chart_id, amount,
 		transdate, project_id, invoice_id)
 		VALUES ($form->{id}, $ref->{chart_id}, $amount,
@@ -889,7 +898,7 @@ sub post_invoice {
     $form->{receivables} = 1;
   }
   
-  my $cleared;
+  my $cleared = 0;
   
   # record payments and offsetting AR
   for $i (1 .. $form->{paidaccounts}) {
@@ -924,7 +933,9 @@ sub post_invoice {
 
       # record payment
       $amount = $form->{"paid_$i"} * -1;
-      $cleared = ($form->{"cleared_$i"}) ? 1 : 0;
+      if ($keepcleared) {
+	$cleared = ($form->{"cleared_$i"}) ? 1 : 0;
+      }
       
       $query = qq|INSERT INTO acc_trans (trans_id, chart_id, amount, transdate,
                   source, memo, cleared)
@@ -1045,10 +1056,11 @@ sub process_assembly {
   my $sth = $dbh->prepare($query);
   $sth->execute || $form->dberror($query);
 
+  my $allocated;
   
   while (my $ref = $sth->fetchrow_hashref(NAME_lc)) {
 
-    my $allocated = 0;
+    $allocated = 0;
     
     $ref->{inventory_accno_id} *= 1;
     $ref->{expense_accno_id} *= 1;
@@ -1144,6 +1156,12 @@ sub cogs {
 sub reverse_invoice {
   my ($dbh, $form) = @_;
   
+  my $query = qq|SELECT id FROM ar
+                 WHERE id = $form->{id}|;
+  my ($id) = $dbh->selectrow_array($query);
+
+  return unless $id;
+
   # reverse inventory items
   my $query = qq|SELECT i.id, i.parts_id, i.qty, i.assemblyitem, p.assembly,
 		 p.inventory_accno_id
@@ -1214,6 +1232,8 @@ sub reverse_invoice {
               WHERE trans_id = $form->{id}|;
   $dbh->do($query) || $form->dberror($query);
 
+  $dbh->commit;
+
 }
 
 
@@ -1666,6 +1686,7 @@ sub exchangerate_defaults {
   }
 
   $form->{$form->{currency}} = $form->{exchangerate} if $form->{exchangerate};
+  $form->{$form->{currency}} ||= 1;
   $form->{$form->{defaultcurrency}} = 1;
 
 }
