@@ -32,7 +32,6 @@ package Inifile;
 sub new {
   my ($type, $file) = @_;
 
-  warn "$type has no copy constructor! creating a new object." if ref($type);
   $type = ref($type) || $type;
   my $self = bless {}, $type;
   $self->add_file($file) if defined $file;
@@ -45,7 +44,10 @@ sub add_file {
   my ($self, $file) = @_;
   
   my $id = "";
+  my %menuorder = ();
 
+  for (@{$self->{ORDER}}) { $menuorder{$_} = 1 }
+  
   open FH, "$file" or Form->error("$file : $!");
 
   while (<FH>) {
@@ -63,7 +65,8 @@ sub add_file {
     if (/^\[/) {
       s/(\[|\])//g;
       $id = $_;
-      push @{$self->{ORDER}}, $_;
+      push @{$self->{ORDER}}, $_ if ! $menuorder{$_};
+      $menuorder{$_} = 1;
       next;
     }
 
