@@ -28,6 +28,7 @@
 
 package JC;
 
+use SL::IS;
 
 sub get_jcitems {
   my ($self, $myconfig, $form) = @_;
@@ -202,8 +203,14 @@ sub jcparts {
   my ($self, $myconfig, $form, $dbh) = @_;
   
   my ($null, $project_id) = split /--/, $form->{projectnumber};
+  $project_id *= 1;
+
+  my $query = qq|SELECT customer_id
+                 FROM project
+		 WHERE id = $project_id|;
+  my ($customer_id) = $dbh->selectrow_array($query);
+  $customer_id *= 1;
   
-  my $query;
   my $where;
 
   if ($form->{project} eq 'job') {
@@ -255,8 +262,12 @@ sub jcparts {
   my $sth = $dbh->prepare($query);
   $sth->execute || $form->dberror($query);
 
+  my $pmh = price_matrix_query($dbh, $project_id, $customer_id);
+  IS::exchangerate_defaults($dbh, $form);
+
   while (my $ref = $sth->fetchrow_hashref(NAME_lc)) {
     $ref->{description} = $ref->{translation} if $ref->{translation};
+    IS::price_matrix($pmh, $ref, $form->datetonum($form->{transdate}), 4, $form, $myconfig);
     push @{ $form->{all_parts} }, $ref;
   }
   $sth->finish;
@@ -366,7 +377,7 @@ sub jcitems {
   ($form->{startdatefrom}, $form->{startdateto}) = $form->from_to($form->{year}, $form->{month}, $form->{interval}) if $form->{year} && $form->{month};
   
   $where .= " AND j.checkedin >= '$form->{startdatefrom}'" if $form->{startdatefrom};
-  $where .= " AND j.checkedout <= date '$form->{startdateto}' + 1" if $form->{startdateto};
+  $where .= " AND j.checkedout < date '$form->{startdateto}' + 1" if $form->{startdateto};
 
   my %ordinal = ( id => 1,
                   description => 2,
@@ -401,7 +412,8 @@ sub jcitems {
   $query = qq|SELECT j.id, j.description, j.qty, j.allocated,
 	      to_char(j.checkedin, 'HH24:MI') AS checkedin,
 	      to_char(j.checkedout, 'HH24:MI') AS checkedout,
-	      to_char(j.checkedin, '$dateformat') AS transdate,
+	      to_char(j.checkedin, 'yyyymmdd') AS transdate,
+	      to_char(j.checkedin, '$dateformat') AS transdatea,
 	      to_char(j.checkedin, 'D') AS weekday,
 	      p.partnumber,
 	      pr.projectnumber, pr.description AS projectdescription,
@@ -420,6 +432,8 @@ sub jcitems {
 
   while ($ref = $sth->fetchrow_hashref(NAME_lc)) {
     $ref->{project} = ($ref->{parts_id}) ? "job" : "project";
+    $ref->{transdate} = $ref->{transdatea};
+    delete $ref->{transdatea};
     push @{ $form->{transactions} }, $ref;
   }
   $sth->finish;
@@ -467,8 +481,8 @@ sub save {
     }
     
   } else {
-    my $uid = time;
-    $uid .= $$;
+    my $uid = localtime;
+    $uid .= "$$";
 
     $query = qq|INSERT INTO jcitems (description)
                 VALUES ('$uid')|;
@@ -531,5 +545,50 @@ sub save {
 
 }
 
+
+sub price_matrix_query {
+  my ($dbh, $project_id, $customer_id) = @_;
+  
+  my $query = qq|SELECT p.id AS parts_id, 0 AS customer_id, 0 AS pricegroup_id,
+              0 AS pricebreak, p.sellprice, NULL AS validfrom, NULL AS validto,
+	      (SELECT substr(curr,1,3) FROM defaults) AS curr, '' AS pricegroup
+              FROM parts p
+	      WHERE p.id = ?
+
+	      UNION
+  
+              SELECT p.*, g.pricegroup
+              FROM partscustomer p
+	      LEFT JOIN pricegroup g ON (g.id = p.pricegroup_id)
+	      WHERE p.parts_id = ?
+	      AND p.customer_id = $customer_id
+	      
+	      UNION
+
+	      SELECT p.*, g.pricegroup 
+	      FROM partscustomer p 
+	      LEFT JOIN pricegroup g ON (g.id = p.pricegroup_id)
+	      JOIN customer c ON (c.pricegroup_id = g.id)
+	      WHERE p.parts_id = ?
+	      AND c.id = $customer_id
+	      
+	      UNION
+
+	      SELECT p.*, '' AS pricegroup
+	      FROM partscustomer p
+	      WHERE p.customer_id = 0
+	      AND p.pricegroup_id = 0
+	      AND p.parts_id = ?
+
+	      ORDER BY customer_id DESC, pricegroup_id DESC, pricebreak
+	      
+	      |;
+  my $sth = $dbh->prepare($query) || $form->dberror($query);
+
+  $sth;
+
+}
+
+
 1;
 
