@@ -36,11 +36,11 @@ sub transactions {
   my $dbh = $form->dbconnect($myconfig);
  
   my $query;
+  my $null;
+  my $var;
   my $ordnumber = 'ordnumber';
   my $quotation = '0';
-  my ($null, $department_id) = split /--/, $form->{department};
-
-  my $department = " AND o.department_id = $department_id" if $department_id;
+  my $department;
   
   my $rate = ($form->{vc} eq 'customer') ? 'buy' : 'sell';
 
@@ -54,6 +54,13 @@ sub transactions {
   my $number = $form->like(lc $form->{$ordnumber});
   my $name = $form->like(lc $form->{$form->{vc}});
   
+  for (qw(department employee)) {
+    if ($form->{$_}) {
+      ($null, $var) = split /--/, $form->{$_};
+      $department .= " AND o.${_}_id = $var";
+    }
+  }
+  
   my $query = qq|SELECT o.id, o.ordnumber, o.transdate, o.reqdate,
                  o.amount, ct.name, o.netamount, o.$form->{vc}_id,
 		 ex.$rate AS exchangerate,
@@ -250,8 +257,8 @@ sub save {
  
   if (! $form->{id}) {
     
-    my $uid = time;
-    $uid .= $$;
+    my $uid = localtime;
+    $uid .= "$$";
     
     $query = qq|INSERT INTO oe (ordnumber, employee_id)
 		VALUES ('$uid', $form->{employee_id})|;
@@ -381,7 +388,7 @@ sub save {
 
   # add up the tax
   my $tax = 0;
-  for (keys %taxaccounts) { $tax += $form->round_amount($taxaccounts{$_}, 2) }
+  for (keys %taxaccounts) { $tax += $taxaccounts{$_} }
   
   $amount = $form->round_amount($netamount + $tax, 2);
   $netamount = $form->round_amount($netamount, 2);
@@ -692,18 +699,18 @@ sub retrieve {
       $tth->finish;
       chop $ref->{taxaccounts};
 
-      # preserve prices
+      # preserve price
       $sellprice = $ref->{sellprice};
-      $listprice = $ref->{listprice};
       
       # multiply by exchangerate
-      for (qw(sellprice listprice)) { $ref->{$_} = $form->round_amount($ref->{$_} * $form->{$form->{currency}}, $decimalplaces) }
+      $ref->{sellprice} = $form->round_amount($ref->{sellprice} * $form->{$form->{currency}}, $decimalplaces);
+      
+      for (qw(listprice lastcost)) { $ref->{$_} = $form->round_amount($ref->{$_} / $form->{$form->{currency}}, $decimalplaces) }
       
       # partnumber and price matrix
       &price_matrix($pmh, $ref, $form->{transdate}, $decimalplaces, $form, $myconfig);
 
       $ref->{sellprice} = $sellprice;
-      $ref->{listprice} = $listprice;
 
       $ref->{partsgroup} = $ref->{partsgrouptranslation} if $ref->{partsgrouptranslation};
       
@@ -911,6 +918,8 @@ sub exchangerate_defaults {
     $eth1->finish;
   }
 
+  $form->{$form->{currency}} = $form->{exchangerate} if $form->{exchangerate};
+  $form->{$form->{currency}} ||= 1;
   $form->{$form->{defaultcurrency}} = 1;
       
 }
@@ -958,6 +967,7 @@ sub order_details {
 	      WHERE id = ?|;
   my $pth = $dbh->prepare($query) || $form->dberror($query);
   
+  my $sortby;
   
   # sort items by project and partsgroup
   for $i (1 .. $form->{rowcount}) {
@@ -1009,13 +1019,22 @@ sub order_details {
 
       }
 
-      push @sortlist, [ $i, qq|$projectnumber$form->{partsgroup}$inventory_accno_id|, $form->{projectnumber}, $projectnumber_id, $form->{partsgroup} ];
+      $sortby = qq|$projectnumber$form->{partsgroup}|;
+      if ($form->{sortby} ne 'runningnumber') {
+	for (qw(partnumber description bin)) {
+	  $sortby .= $form->{"${_}_$i"} if $form->{sortby} eq $_;
+	}
+      }
+
+      push @sortlist, [ $i, qq|$projectnumber$form->{partsgroup}$inventory_accno_id|, $form->{projectnumber}, $projectnumber_id, $form->{partsgroup}, $sortby ];
     }
 
   }
 
+  delete $form->{projectnumber};
+  
   # sort the whole thing by project and group
-  @sortlist = sort { $a->[1] cmp $b->[1] } @sortlist;
+  @sortlist = sort { $a->[5] cmp $b->[5] } @sortlist;
   
 
   # if there is a warehouse limit picking
@@ -1075,7 +1094,7 @@ sub order_details {
 	  }
 
 	  push(@{ $form->{description} }, $item->[2]);
-	  for (qw(taxrates runningnumber number sku qty ship unit bin serialnumber reqdate projectnumber sellprice listprice netprice discount discountrate linetotal weight itemnotes)) { push(@{ $form->{$_} }, "") }
+	  for (qw(taxrates runningnumber number sku qty ship unit bin serialnumber requiredate projectnumber sellprice listprice netprice discount discountrate linetotal weight itemnotes)) { push(@{ $form->{$_} }, "") }
 	  push(@{ $form->{lineitems} }, { amount => 0, tax => 0 });
 	}
       }
@@ -1102,7 +1121,7 @@ sub order_details {
       push(@{ $form->{unit} }, qq|$form->{"unit_$i"}|);
       push(@{ $form->{bin} }, qq|$form->{"bin_$i"}|);
       push(@{ $form->{serialnumber} }, qq|$form->{"serialnumber_$i"}|);
-      push(@{ $form->{reqdate} }, qq|$form->{"reqdate_$i"}|);
+      push(@{ $form->{requiredate} }, qq|$form->{"reqdate_$i"}|);
       push(@{ $form->{projectnumber} }, qq|$form->{"projectnumber_$i"}|);
       
       push(@{ $form->{sellprice} }, $form->{"sellprice_$i"});
@@ -1189,7 +1208,7 @@ sub order_details {
       }
 
       push(@{ $form->{lineitems} }, { amount => $linetotal, tax => $form->round_amount($tax, 2) });
-      push(@{ $form->{taxrates} }, join /:/, sort { $a <=> $b } @taxrates);
+      push(@{ $form->{taxrates} }, join ' ', sort { $a <=> $b } @taxrates);
 	
       if ($form->{"assembly_$i"}) {
 	$form->{stagger} = -1;
@@ -1213,7 +1232,7 @@ sub order_details {
 	      push(@{ $form->{part} }, NULL);
 	    }
 
-	    for (qw(taxrates runningnumber number sku qty ship unit bin serialnumber reqdate projectnumber sellprice listprice netprice discount discountrate weight itemnotes)) { push(@{ $form->{$_} }, "") }
+	    for (qw(taxrates runningnumber number sku qty ship unit bin serialnumber requiredate projectnumber sellprice listprice netprice discount discountrate weight itemnotes)) { push(@{ $form->{$_} }, "") }
 
 	    push(@{ $form->{description} }, $form->{groupsubtotaldescription});
 
@@ -1240,7 +1259,7 @@ sub order_details {
 	      push(@{ $form->{part} }, NULL);
 	    } 
 	    
-	    for (qw(taxrates runningnumber number sku qty ship unit bin serialnumber reqdate projectnumber sellprice listprice netprice discount discountrate weight itemnotes)) { push(@{ $form->{$_} }, "") }
+	    for (qw(taxrates runningnumber number sku qty ship unit bin serialnumber requiredate projectnumber sellprice listprice netprice discount discountrate weight itemnotes)) { push(@{ $form->{$_} }, "") }
 
 	    push(@{ $form->{description} }, $form->{groupsubtotaldescription});
 	    push(@{ $form->{linetotal} }, $form->format_amount($myconfig, $subtotal, 2));
@@ -1308,7 +1327,8 @@ sub order_details {
 
   $form->{text_decimal} = $c->num2text($form->{decimal} * 1);
   $form->{text_amount} = $c->num2text($whole);
-  
+  $form->{integer_amount} = $whole;
+
   # format amounts
   $form->{quototal} = $form->{ordtotal} = $form->format_amount($myconfig, $form->{ordtotal}, 2);
 
@@ -1369,7 +1389,7 @@ sub assembly_details {
     }
    
     if ($form->{grouppartsgroup} && $ref->{partsgroup} ne $sm) {
-      for (qw(taxrates number sku unit qty runningnumber ship bin serialnumber reqdate projectnumber sellprice listprice netprice discount discountrate linetotal weight itemnotes)) { push(@{ $form->{$_} }, "") }
+      for (qw(taxrates number sku unit qty runningnumber ship bin serialnumber requiredate projectnumber sellprice listprice netprice discount discountrate linetotal weight itemnotes)) { push(@{ $form->{$_} }, "") }
       $sm = ($form->{"a_partsgroup"}) ? $form->{"a_partsgroup"} : "";
       push(@{ $form->{description} }, "$spacer$sm");
       
@@ -1380,7 +1400,7 @@ sub assembly_details {
     if ($form->{stagger}) {
      
       push(@{ $form->{description} }, qq|$spacer$form->{"a_partnumber"}, $form->{"a_description"}|);
-      for (qw(taxrates number sku runningnumber ship serialnumber reqdate projectnumber sellprice listprice netprice discount discountrate linetotal weight itemnotes)) { push(@{ $form->{$_} }, "") }
+      for (qw(taxrates number sku runningnumber ship serialnumber requiredate projectnumber sellprice listprice netprice discount discountrate linetotal weight itemnotes)) { push(@{ $form->{$_} }, "") }
       
     } else {
       
@@ -1388,7 +1408,7 @@ sub assembly_details {
       push(@{ $form->{sku} }, $form->{"a_partnumber"});
       push(@{ $form->{number} }, $form->{"a_partnumber"});
       
-      for (qw(taxrates runningnumber ship serialnumber reqdate projectnumber sellprice listprice netprice discount discountrate linetotal weight itemnotes)) { push(@{ $form->{$_} }, "") }
+      for (qw(taxrates runningnumber ship serialnumber requiredate projectnumber sellprice listprice netprice discount discountrate linetotal weight itemnotes)) { push(@{ $form->{$_} }, "") }
       
     }
 
@@ -1629,16 +1649,18 @@ sub adj_inventory {
 
     $ith->execute($ref->{id}, $ref->{id}) || $form->dberror($query);
 
+    my $ship = $ref->{ship};
     while (my $inv = $ith->fetchrow_hashref(NAME_lc)) {
 
-      if (($qty = (($inv->{total} * $ml) - $ref->{ship})) >= 0) {
-	$qty = $inv->{qty} if ($qty > ($inv->{qty} * $ml));
+      if (($qty = (($inv->{total} * $ml) - $ship)) >= 0) {
+	$qty = $inv->{qty} * $ml if ($qty > ($inv->{qty} * $ml));
 	
 	$form->update_balance($dbh,
                               "inventory",
                               "qty",
                               qq|$oid{$myconfig->{dbdriver}} = $inv->{oid}|,
                               $qty * -1 * $ml);
+	$ship -= $qty;
       }
     }
     $ith->finish;
@@ -1937,6 +1959,8 @@ sub generate_orders {
 
   my $description;
   my $unit;
+
+  my $sellprice;
   
   foreach $vendor_id (keys %a) {
     
@@ -1960,8 +1984,8 @@ sub generate_orders {
     $curr ||= $form->{defaultcurrency};
     $taxincluded *= 1;
     
-    my $uid = time;
-    $uid .= $$;
+    my $uid = localtime;
+    $uid .= "$$";
  
     $query = qq|INSERT INTO oe (ordnumber)
 		VALUES ('$uid')|;
@@ -1979,7 +2003,12 @@ sub generate_orders {
     
     foreach my $parts_id (keys %{ $a{$vendor_id} }) {
 
-      my $sellprice = $form->round_amount($a{$vendor_id}{$parts_id}{lastcost} / $form->{$curr} * $form->{$a{$vendor_id}{$parts_id}{curr}}, 2);
+      if (($form->{$curr} * $form->{$a{$vendor_id}{$parts_id}{curr}}) > 0) {
+	$sellprice = $a{$vendor_id}{$parts_id}{lastcost} / $form->{$curr} * $form->{$a{$vendor_id}{$parts_id}{curr}};
+      } else {
+	$sellprice = $a{$vendor_id}{$parts_id}{lastcost};
+      }
+      $sellprice = $form->round_amount($sellprice, 2);
       
       my $linetotal = $form->round_amount($sellprice * $a{$vendor_id}{$parts_id}{qty}, 2);
        
@@ -2036,7 +2065,8 @@ sub generate_orders {
 		taxincluded = '$taxincluded',
 		curr = '$curr',
 		employee_id = $employee_id,
-		department_id = '$department_id'
+		department_id = '$department_id',
+		ponumber = |.$dbh->quote($form->{ponumber}).qq|
 		WHERE id = $id|;
     $dbh->do($query) || $form->dberror($query);
     
@@ -2105,11 +2135,14 @@ sub consolidate_orders {
   }
 
   
-  my $ordnumber;
+  my $ordnumber = $form->{ordnumber};
   my $numberfld = ($form->{vc} eq 'customer') ? 'sonumber' : 'ponumber';
   
-  my $uid = time;
-  $uid .= $$;
+  my ($department, $department_id) = $form->{department};
+  $department_id *= 1;
+  
+  my $uid = localtime;
+  $uid .= "$$";
 
   my @orderitems = ();
  
@@ -2149,10 +2182,10 @@ sub consolidate_orders {
 	    
       }
 
-      $ordnumber = $form->update_defaults($myconfig, $numberfld, $dbh);
+      $ordnumber ||= $form->update_defaults($myconfig, $numberfld, $dbh);
     
       $query = qq|INSERT INTO oe (ordnumber)
-		  VALUES ($uid)|;
+		  VALUES ('$uid')|;
       $dbh->do($query) || $form->dberror($query);
 
       $query = qq|SELECT id
@@ -2177,14 +2210,16 @@ sub consolidate_orders {
 		  employee_id = $ref->{employee_id},
 		  intnotes = |.$dbh->quote($ref->{intnotes}).qq|,
 		  shipvia = |.$dbh->quote($ref->{shipvia}).qq|,
-		  language_code = '$ref->{language_code}'
+		  language_code = '$ref->{language_code}',
+		  ponumber = |.$dbh->quote($form->{ponumber}).qq|,
+		  department_id = $department_id
 		  WHERE id = $id|;
       $dbh->do($query) || $form->dberror($query);
 	  
 
       # add items
       foreach $item (@orderitems) {
-	$item->{project_id} *= 1;
+	for (qw(qty sellprice discount project_id ship)) { $item->{$_} *= 1 }
 	$query = qq|INSERT INTO orderitems (
 		    trans_id, parts_id, description,
 		    qty, sellprice, discount,
