@@ -429,6 +429,9 @@ sub payments_footer {
   
   $form->{DF}{$form->{format}} = "selected";
 
+  $transdate = $form->datetonum(\%myconfig, $form->{datepaid});
+  $closedto = $form->datetonum(\%myconfig, $form->{closedto});
+  
   if ($latex) {
    
     $media = qq|<select name=media>
@@ -466,6 +469,11 @@ sub payments_footer {
   if (! $latex) {
     delete $button{'Print'};
   }
+
+  if ($transdate <= $closedto) {
+    for ('Post', 'Print') { delete $button{$_} }
+    $media = $format = "";
+  }
   
   for (sort { $button{$a}->{ndx} <=> $button{$b}->{ndx} } keys %button) { $form->print_button(\%button, $_) }
 
@@ -1020,6 +1028,9 @@ sub payment_footer {
 
   $form->{DF}{$form->{format}} = "selected";
 
+  $transdate = $form->datetonum(\%myconfig, $form->{datepaid});
+  $closedto = $form->datetonum(\%myconfig, $form->{closedto});
+
   if ($latex) {
     if ($form->{selectlanguage}) {
       $form->{"selectlanguage"} = $form->unescape($form->{"selectlanguage"});
@@ -1061,6 +1072,11 @@ sub payment_footer {
     delete $button{'Print'};
   }
 
+  if ($transdate <= $closedto) {
+    for ('Post', 'Print') { delete $button{$_} }
+    $media = $format = "";
+  }
+
   for (sort { $button{$a}->{ndx} <=> $button{$b}->{ndx} } keys %button) { $form->print_button(\%button, $_) }
   
   $media =~ s/(<option value="\Q$form->{media}\E")/$1 selected/;
@@ -1219,6 +1235,7 @@ sub print_form {
   $form->{decimal} = substr($form->{decimal}, 0, 2);
   $form->{text_decimal} = $c->num2text($form->{decimal} * 1);
   $form->{text_amount} = $c->num2text($whole);
+  $form->{integer_amount} = $whole;
 
   $datepaid = $form->datetonum(\%myconfig, $form->{datepaid});
   ($form->{yyyy}, $form->{mm}, $form->{dd}) = $datepaid =~ /(....)(..)(..)/;
