@@ -125,7 +125,7 @@ sub history {
 	      </tr>
 	      <tr>
 		<td>
-		<input name="l_partnumber" type=checkbox class=checkbox value=Y checked>&nbsp;|.$locale->text('Partnumber').qq|
+		<input name="l_partnumber" type=checkbox class=checkbox value=Y checked>&nbsp;|.$locale->text('Part Number').qq|
 		</td>
 		<td>
 		<input name="l_description" type=checkbox class=checkbox value=Y checked>&nbsp;|.$locale->text('Description').qq|
@@ -341,6 +341,7 @@ sub search {
 
   $orphan = qq|
 	<tr>
+	  <td></td>
 	  <td><input name=status class=radio type=radio value=all checked>&nbsp;|.$locale->text('All').qq|
 	  <input name=status class=radio type=radio value=active>&nbsp;|.$locale->text('Active').qq|
 	  <input name=status class=radio type=radio value=inactive>&nbsp;|.$locale->text('Inactive').qq|
@@ -468,12 +469,11 @@ sub search_name {
     </td>
   </tr>
 
-  $orphan
-
   <tr>
     <td>
       <table>
 
+	$orphan
 	$transactions
 	$include
 
@@ -698,7 +698,7 @@ sub list_names {
   $column_header{bcc} = qq|<th><a class=listheading href=$href&sort=cc>|.$locale->text('Bcc').qq|</a></th>|;
   $column_header{notes} = qq|<th><a class=listheading href=$href&sort=notes>|.$locale->text('Notes').qq|</a></th>|;
   $column_header{discount} = qq|<th class=listheading>%</th>|;
-  $column_header{terms} = qq|<th class=listheading>Terms</th>|;
+  $column_header{terms} = qq|<th class=listheading>|.$locale->text('Terms').qq|</th>|;
   
   $column_header{taxnumber} = qq|<th><a class=listheading href=$href&sort=taxnumber>|.$locale->text('Tax Number').qq|</a></th>|;
   $column_header{taxaccount} = qq|<th class=listheading>|.$locale->text('Tax Account').qq|</th>|;
@@ -1078,7 +1078,7 @@ sub list_history {
   $form->{callback} = "$callback&sort=$form->{sort}";
   $callback = $form->escape($form->{callback});
 
-  $column_header{partnumber} = qq|<th><a class=listheading href=$href&sort=partnumber>|.$locale->text('Partnumber').qq|</a></th>|;
+  $column_header{partnumber} = qq|<th><a class=listheading href=$href&sort=partnumber>|.$locale->text('Part Number').qq|</a></th>|;
   $column_header{description} = qq|<th><a class=listheading href=$href&sort=description>|.$locale->text('Description').qq|</a></th>|;
 
   if ($form->{history} eq 'summary') {
@@ -2117,7 +2117,7 @@ sub update {
 	$pricebreak = $form->{"pricebreak_$i"};
 	$lastcost = $form->{"lastcost_$i"};
 	
-	for (qw(partnumber description)) { $form->{item_list}[$i]{$_} = $form->quote($form->{item_list}[$i]{$_}) }
+	for (qw(partnumber description)) { $form->{item_list}[0]{$_} = $form->quote($form->{item_list}[0]{$_}) }
 	for (keys %{ $form->{item_list}[0] }) { $form->{"${_}_$i"} = $form->{item_list}[0]{$_} }
 
         if ($form->{db} eq 'customer') {
@@ -2132,7 +2132,7 @@ sub update {
 	  
 	} else {
 
-          foreach $j (1 .. $form->{rowcount}) {
+          foreach $j (1 .. $form->{rowcount} - 1) {
 	    if ($form->{"sku_$j"} eq $form->{"partnumber_$i"}) {
 	      $form->error($locale->text('Item already on pricelist!'));
 	    }
@@ -2212,7 +2212,7 @@ sub select_item {
 
     for (qw(partnumber description unit)) { $ref->{$_} = $form->quote($ref->{$_}) }
     
-    $column_data{ndx} = qq|<td><input name="ndx_$i" class=checkbox type=checkbox value=$i $checked></td>|;
+    $column_data{ndx} = qq|<td><input name="ndx_$i" class=checkbox type=checkbox value=$i></td>|;
 
     for (qw(partnumber description partsgroup unit)) { $column_data{$_} = qq|<td>$ref->{$_}&nbsp;</td>| }
 
@@ -2283,7 +2283,9 @@ sub item_selected {
 
     if ($form->{"ndx_$j"}) {
 
-      next if $id{$form->{"new_id_$j"}};
+      if ($id{$form->{"new_id_$j"}}) {
+	next if $form->{db} eq 'vendor';
+      }
       
       for (qw(id partnumber description unit sellprice lastcost)) {
 	$form->{"${_}_$i"} = $form->{"new_${_}_$j"};
@@ -2302,6 +2304,7 @@ sub item_selected {
   # delete all the new_ variables
   for $i (1 .. $form->{lastndx}) {
     for (qw(id partnumber description unit sellprice lastcost partsgroup partsgroup_id)) { delete $form->{"new_${_}_$i"} }
+    delete $form->{"ndx_$i"};
   }
   
   for (qw(ndx lastndx nextsub)) { delete $form->{$_} }
