@@ -184,6 +184,7 @@ sub prepare_invoice {
 
   $form->{type} = "invoice";
   $form->{formname} = "invoice";
+  $form->{sortby} ||= "runningnumber";
   $form->{format} = "postscript" if $myconfig{printer};
   $form->{media} = $myconfig{printer};
 
@@ -638,7 +639,7 @@ sub form_footer {
 
     if ($form->{id}) {
       
-      if ($form->{locked}) {
+      if ($form->{locked} || $transdate <= $closedto) {
 	for ("Post", "Print and Post", "Delete") { delete $button{$_} }
       }
      
