@@ -167,7 +167,7 @@ sub display_row {
     if ($form->{"qty_$i"} != $form->{"oldqty_$i"}) {
       # check pricematrix
       @a = split / /, $form->{"pricematrix_$i"};
-      if (scalar @a > 2) {
+      if (scalar @a > 1) {
 	foreach $item (@a) {
 	  ($q, $p) = split /:/, $item;
 	  if (($p * 1) && ($form->{"qty_$i"} >= ($q * 1))) {
@@ -444,6 +444,7 @@ sub item_selected {
 
   $i = $form->{rowcount} - 1;
   $i = $form->{assembly_rows} - 1 if ($form->{item} eq 'assembly');
+  $qty = ($form->{"qty_$form->{rowcount}"}) ? $form->{"qty_$form->{rowcount}"} : 1;
 
   for $j (1 .. $form->{lastndx}) {
     
@@ -451,7 +452,7 @@ sub item_selected {
 
       $i++;
   
-      $form->{"qty_$i"} = 1;
+      $form->{"qty_$i"} = $qty;
       $form->{"discount_$i"} = $form->{discount} * 100;
       $form->{"reqdate_$i"} = $form->{reqdate} if $form->{type} !~ /_quotation/;
 
@@ -552,43 +553,34 @@ sub new_item {
   $i = $form->{rowcount};
   for (qw(partnumber description)) { $form->{"${_}_$i"} = $form->quote($form->{"${_}_$i"}) }
 
+  %button = ('Add Part' => { ndx => 1, key => 'P', value => $locale->text('Add Part') },
+             'Add Service' => { ndx => 2, key => 'P', value => $locale->text('Add Service') }
+	    );
+
+  delete $button{'Add Part'} if $myconfig{acs} =~ /Goods \& Services--Add Part/;
+  delete $button{'Add Service'} if $myconfig{acs} =~ /Goods \& Services--Add Service/;
+  
   $form->header;
 
   print qq|
 <body>
 
-<h4 class=error>|.$locale->text('Item not on file!').qq|</h4>|;
-
-  if ($myconfig{acs} !~ /(Goods \& Services--Add Part|Goods \& Services--Add Service)/) {
-
-    print qq|
-<h4>|.$locale->text('What type of item is this?').qq|</h4>
+<h2 class=error>|.$locale->text('Error!').qq|</h2>
+<h4 class=error>|.$locale->text('Item not on file!').qq|</h4>
 
 <form method=post action=ic.pl>
 
-<p>
-
-  <input class=radio type=radio name=item value=part checked>&nbsp;|.$locale->text('Part')
-.qq|<br>
-  <input class=radio type=radio name=item value=service>&nbsp;|.$locale->text('Service')
-
-.qq|
 <input type=hidden name=partnumber value="$form->{"partnumber_$i"}">
 <input type=hidden name=description value="$form->{"description_$i"}">
-<input type=hidden name=nextsub value=add>
-<input type=hidden name=action value=add>
 |;
 
   $form->hide_form(qw(previousform rowcount path login sessionid));
 
+  for (sort { $button{$a}->{ndx} <=> $button{$b}->{ndx} } keys %button) { $form->print_button(\%button, $_) }
+  
   print qq|
-<p>
-<input class=submit type=submit name=action value="|.$locale->text('Continue').qq|">
 </form>
-|;
-  }
 
-  print qq|
 </body>
 </html>
 |;
@@ -701,7 +693,7 @@ sub check_form {
     
     for (qw(rop stock markup)) { $form->{$_} = $form->parse_amount(\%myconfig, $form->{$_}) }
    
-    @flds = qw(id qty unit bom adj partnumber description sellprice listprice weight runningnumber partsgroup);
+    @flds = qw(id qty unit bom adj partnumber description sellprice listprice lastcost weight assembly runningnumber partsgroup);
     $count = 0;
     @a = ();
     
@@ -1124,44 +1116,58 @@ sub print_options {
 |;
   }
 
+# $locale->text('Printed')
+# $locale->text('E-mailed')
+# $locale->text('Queued')
+# $locale->text('Scheduled')
+
+  %status = ( printed => 'Printed',
+              emailed => 'E-mailed',
+	      queued  => 'Queued',
+	      recurring => 'Scheduled' );
+
+  print qq|<td align=right width=90%>|;
+
+  for (qw(printed emailed queued recurring)) {
+    if ($form->{$_} =~ /$form->{formname}/) {
+      print $locale->text($status{$_}).qq|<br>|;
+    }
+  }
+
+  print qq|
+    </td>
+  </tr>
+|;
+
   $form->{groupprojectnumber} = "checked" if $form->{groupprojectnumber};
   $form->{grouppartsgroup} = "checked" if $form->{grouppartsgroup};
 
+  for (qw(runningnumber partnumber description bin)) { $sortby{$_} = "checked" if $form->{sortby} eq $_ }
+  
   print qq|
-    <td nowrap>|.$locale->text('Group Items').qq|</td>
-    <td nowrap>
+  <tr>
+    <td colspan=3>|.$locale->text('Group by').qq| ->
     <input name=groupprojectnumber type=checkbox class=checkbox $form->{groupprojectnumber}>
     |.$locale->text('Project').qq|
     <input name=grouppartsgroup type=checkbox class=checkbox $form->{grouppartsgroup}>
     |.$locale->text('Group').qq|
     </td>
-|;
 
-  print qq|<td align=right width=90%>|;
-
-  if ($form->{printed} =~ /$form->{formname}/) {
-    print $locale->text('Printed').qq|<br>|;
-  }
-  
-  if ($form->{emailed} =~ /$form->{formname}/) {
-    print $locale->text('E-mailed').qq|<br>|;
-  }
-
-  if ($form->{queued} =~ /$form->{formname}/) {
-    print $locale->text('Queued');
-  }
-  
-  if ($form->{recurring}) {
-    print $locale->text('Scheduled');
-  }
-  
-  print qq|
+    <td colspan=3>|.$locale->text('Sort by').qq| ->
+    <input name=sortby type=radio class=radio value=runningnumber $sortby{runningnumber}>
+    |.$locale->text('Item').qq|
+    <input name=sortby type=radio class=radio value=partnumber $sortby{partnumber}>
+    |.$locale->text('Number').qq|
+    <input name=sortby type=radio class=radio value=description $sortby{description}>
+    |.$locale->text('Description').qq|
+    <input name=sortby type=radio class=radio value=bin $sortby{bin}>
+    |.$locale->text('Bin').qq|
     </td>
+    
   </tr>
 </table>
 |;
 
-
 }
 
 
@@ -1550,6 +1556,7 @@ sub ship_to {
   $form->{title} = $locale->text('Ship to');
 
   for (qw(exchangerate creditlimit creditremaining)) { $form->{$_} = $form->parse_amount(\%myconfig, $form->{$_}) }
+  for (1 .. $form->{paidaccounts}) { $form->{"paid_$_"} = $form->parse_amount(\%myconfig, $form->{"paid_$_"}) }
 
   # get details for name
   &{ "$form->{vc}_details" };
