@@ -5,6 +5,7 @@
 #  Author: DWS Systems Inc.
 #     Web: http://www.sql-ledger.org
 #
+#  Contributors:
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -67,8 +68,7 @@ sub login_screen {
   $form->{stylesheet} = "sql-ledger.css";
   $form->{favicon} = "sql-ledger.ico";
 
-  $form->{endsession} = 1;
-  $form->header(1);
+  $form->header;
 
   if ($form->{login}) {
    $sf = qq|function sf() { document.login.password.focus(); }|;
@@ -108,7 +108,7 @@ $sf
 <center>
 <table class=login border=3 cellpadding=20>
   <tr>
-    <td class=login align=center><a href="http://www.sql-ledger.org" target=_top><img src=sql-ledger.gif border=0>&trade;</a>
+    <td class=login align=center><a href="http://www.sql-ledger.org" target=_top><img src=sql-ledger.gif border=0></a>
 <h1 class=login align=center>|.$locale->text('Version').qq| $form->{version}
 </h1>
 
@@ -158,6 +158,11 @@ sub selectdataset {
     $form->{stylesheet} = "sql-ledger.css";
   }
 
+  if (-f sql-ledger.ico) {
+    $form->{favicon} = "sql-ledger.ico";
+  }
+  
+  delete $self->{sessioncookie};
   $form->header(1);
 
   print qq|
@@ -170,7 +175,7 @@ sub selectdataset {
 <center>
 <table class=login border=3 cellpadding=20>
   <tr>
-    <td class=login align=center><a href="http://www.sql-ledger.org" target=_top><img src=sql-ledger.gif border=0>&trade;</a>
+    <td class=login align=center><a href="http://www.sql-ledger.org" target=_top><img src=sql-ledger.gif border=0></a>
 <h1 class=login align=center>|.$locale->text('Version').qq| $form->{version}
 </h1>
 
@@ -300,7 +305,7 @@ sub login {
 
       print $locale->text('done');
 
-      print "<p><a href=menu.pl?login=$form->{login}&sessionid=$form->{sessionid}&path=$form->{path}&action=display&main=company_logo&js=$form->{js}>".$locale->text('Continue')."</a>";
+      print "<p><a href=menu.pl?login=$form->{login}&path=$form->{path}&action=display&main=company_logo&js=$form->{js}>".$locale->text('Continue')."</a>";
 
       exit;
     }
@@ -308,9 +313,13 @@ sub login {
     $form->error($err[$errno]);
   }
 
+  $user->create_config("$userspath/$form->{login}.conf");
+  $form->{timeout} = $user->{timeout};
+  $form->{sessioncookie} = $user->{sessioncookie};
+
   # made it this far, setup callback for the menu
   $form->{callback} = "menu.pl?action=display";
-  for (qw(login path js)) { $form->{callback} .= "&$_=$form->{$_}" }
+  for (qw(login path password js sessioncookie)) { $form->{callback} .= "&$_=$form->{$_}" }
   
   # check for recurring transactions
   if ($user->{acs} !~ /Recurring Transactions/) {
@@ -340,10 +349,7 @@ sub login {
 sub logout {
 
   $form->{callback} = "$form->{script}?path=$form->{path}&login=$form->{login}";
-
-  $form->{endsession} = 1;
-  
-  $form->redirect;
+  $form->redirect($locale->text('You are logged out'));
 
 }
 
