@@ -45,6 +45,7 @@ $| = 1;
 
 eval { require "sql-ledger.conf"; };
 
+
 if ($ENV{CONTENT_LENGTH}) {
   read(STDIN, $_, $ENV{CONTENT_LENGTH});
 }
@@ -68,6 +69,13 @@ $0 =~ tr/\\/\//;
 $pos = rindex $0, '/';
 $script = substr($0, $pos + 1);
 
+@scripts = qw(login.pl admin.pl custom_login.pl custom_admin.pl);
+
+if (grep !/^\Q$form{script}\E/, @scripts) {
+  print "Content-Type: text/html\n\n" if $ENV{HTTP_USER_AGENT};
+  print "\nAccess denied!\n";
+  exit;
+}
 
 if (-e "$userspath/nologin" && $script ne 'admin.pl') {
   print "Content-Type: text/html\n\n" if $ENV{HTTP_USER_AGENT};
@@ -97,7 +105,6 @@ if ($form{path}) {
       $form{terminal} = "lynx";
       if ($ENV{HTTP_USER_AGENT} !~ /lynx/i) {
 	$form{terminal} = "mozilla";
-	$form{jsc} = 1;
       }
     } else {
       if ($ENV{TERM} =~ /xterm/) {
@@ -111,6 +118,8 @@ if ($form{path}) {
 
 
   if ($form{terminal}) {
+    $form{terminal} =~ s/%2f/\//gi;
+    $form{terminal} =~ s/\.\.\///g;
 
     $ARGV[0] = "path=bin/$form{terminal}&script=$script";
     map { $ARGV[0] .= "&${_}=$form{$_}" } keys %form;
