@@ -124,10 +124,10 @@ insert into chart (accno,description,charttype,gifi_accno,category,link) values
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('34100', 'Da z pjm','A','','L','');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('34200', 'Ostatn pm dan','A','','L','');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('34300', 'Da z pidan hodnoty - ztovn','A','','L','');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('34311', 'DPH 5% vstup','A','','L','AP_tax:IC_taxpart:IC_taxservice:CT_tax');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('34312', 'DPH 22% vstup','A','','L','AP_tax:IC_taxpart:IC_taxservice:CT_tax');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('34321', 'DPH 5% vstup','A','','L','AR_tax:IC_taxpart:IC_taxservice:CT_tax');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('34322', 'DPH 22% vstup','A','','L','AR_tax:IC_taxpart:IC_taxservice:CT_tax');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('34311', 'DPH 5% vstup','A','','L','AP_tax:IC_taxpart:IC_taxservice');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('34312', 'DPH 22% vstup','A','','L','AP_tax:IC_taxpart:IC_taxservice');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('34321', 'DPH 5% vstup','A','','L','AR_tax:IC_taxpart:IC_taxservice');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('34322', 'DPH 22% vstup','A','','L','AR_tax:IC_taxpart:IC_taxservice');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('34500', 'Ostatn dan a poplatky','A','','L','');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('34600', 'Dotace ze sttnho rozpotu','A','','L','');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('34700', 'Ostatn dotace','A','','L','');
