@@ -12,14 +12,14 @@ INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('3841','Bank 2','A','A','AR_paid:AP_paid','384');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4540','Belfldi Szlltk','A','L','AP','454');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4541','Klfldi szlltk','A','L','AP','454');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4660','Visszaignyelhet FA 25%','A','L','AP_tax:IC_taxpart:IC_taxservice:CT_tax','466');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4661','Visszaignyelhet FA 12%','A','L','AP_tax:IC_taxpart:IC_taxservice:CT_tax','466');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4662','Visszaignyelhet FA 5%','A','L','AP_tax:IC_taxpart:IC_taxservice:CT_tax','466');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4663','Visszaignyelhet FA admentes','A','L','AP_tax:IC_taxpart:IC_taxservice:CT_tax','466');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4670','Fizetend FA 25%','A','L','AR_tax:IC_taxpart:IC_taxservice:CT_tax','467');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4671','Fizetend FA 15%','A','L','AR_tax:IC_taxpart:IC_taxservice:CT_tax','467');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4672','Fizetend FA 5%','A','L','AR_tax:IC_taxpart:IC_taxservice:CT_tax','467');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4673','Fizetend FA admentes','A','L','AR_tax:IC_taxpart:IC_taxservice:CT_tax','467');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4660','Visszaignyelhet FA 25%','A','L','AP_tax:IC_taxpart:IC_taxservice','466');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4661','Visszaignyelhet FA 12%','A','L','AP_tax:IC_taxpart:IC_taxservice','466');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4662','Visszaignyelhet FA 5%','A','L','AP_tax:IC_taxpart:IC_taxservice','466');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4663','Visszaignyelhet FA admentes','A','L','AP_tax:IC_taxpart:IC_taxservice','466');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4670','Fizetend FA 25%','A','L','AR_tax:IC_taxpart:IC_taxservice','467');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4671','Fizetend FA 15%','A','L','AR_tax:IC_taxpart:IC_taxservice','467');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4672','Fizetend FA 5%','A','L','AR_tax:IC_taxpart:IC_taxservice','467');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('4673','Fizetend FA admentes','A','L','AR_tax:IC_taxpart:IC_taxservice','467');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5200','Brleti dj','A','E','AP_amount','520');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5210','Telefon','A','E','AP_amount','521');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('5990','Kltsgek','A','E','IC_expense','599');
