@@ -63,9 +63,9 @@ INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES
 INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('111031', 'Fondo svalutazione crediti', 'A', '1.C.II.1', 'A', '');
 INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('111032', 'Fondo rischi su crediti', 'A', '1.C.II.1', 'A', '');
 INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('112000', 'CREDITI DIVERSI', 'H', '', 'A', '');
-INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('112001', 'IVA nostro credito  4%', 'A', '1.C.II.5', 'A', 'AP_tax:CT_tax:IC_taxpart:IC_taxservice');
-INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('112002', 'IVA nostro credito 10%', 'A', '1.C.II.5', 'A', 'AP_tax:CT_tax:IC_taxpart:IC_taxservice');
-INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('112004', 'IVA nostro credito 20%', 'A', '1.C.II.5', 'A', 'AP_tax:CT_tax:IC_taxpart:IC_taxservice');
+INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('112001', 'IVA nostro credito  4%', 'A', '1.C.II.5', 'A', 'AP_tax:IC_taxpart:IC_taxservice');
+INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('112002', 'IVA nostro credito 10%', 'A', '1.C.II.5', 'A', 'AP_tax:IC_taxpart:IC_taxservice');
+INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('112004', 'IVA nostro credito 20%', 'A', '1.C.II.5', 'A', 'AP_tax:IC_taxpart:IC_taxservice');
 INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('112062', 'Erario c/acconto IVA', 'A', '1.C.II.5', 'A', '');
 INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('112063', 'Credito per IVA', 'A', '1.C.II.5', 'A', '');
 INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('112071', 'Personale c/acconti', 'A', '1.C.II.5', 'A', '');
@@ -105,9 +105,9 @@ INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES
 INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('225002', 'Cambiali passive', 'A', '2.D.6', 'L', 'AP_paid');
 INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('225003', 'Fatture da ricevere', 'A', '2.D.6', 'L', '');
 INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('226000', 'DEBITI TRIBUTARI', 'H', '', 'L', '');
-INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('226001', 'IVA nostro debito  4%', 'A', '2.D.13', 'L', 'AR_tax:CT_tax:IC_taxpart:IC_taxservice');
-INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('226002', 'IVA nostro debito 10%', 'A', '2.D.13', 'L', 'AR_tax:CT_tax:IC_taxpart:IC_taxservice');
-INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('226004', 'IVA nostro debito 20%', 'A', '2.D.13', 'L', 'AR_tax:CT_tax:IC_taxpart:IC_taxservice');
+INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('226001', 'IVA nostro debito  4%', 'A', '2.D.13', 'L', 'AR_tax:IC_taxpart:IC_taxservice');
+INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('226002', 'IVA nostro debito 10%', 'A', '2.D.13', 'L', 'AR_tax:IC_taxpart:IC_taxservice');
+INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('226004', 'IVA nostro debito 20%', 'A', '2.D.13', 'L', 'AR_tax:IC_taxpart:IC_taxservice');
 INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('226062', 'Debito per IVA', 'A', '2.D.13', 'L', '');
 INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('226065', 'Erario c/ritenute da versarare', 'A', '2.D.13', 'L', '');
 INSERT INTO chart (accno,description,charttype,gifi_accno,category,link) VALUES ('226066', 'Altri debiti verso l\'erario', 'A', '2.D.13', 'L', '');
