@@ -243,8 +243,8 @@ INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8820','Nodoklis par dabas resursu izmantoanu no peas  maksjam da','A','E','','');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('8810','Nodoklis no peas','A','E','','');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('1330','Ldzdalbas saistto uzmumu kapitl','A','A','','');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2354','PVN samaksts 18%','A','E','AP_tax:IC_taxpart:IC_taxservice:CT_tax','');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2352','PVN ieemtais 18%','A','L','AR_tax:IC_taxpart:IC_taxservice:CT_tax','');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2354','PVN samaksts 18%','A','E','AP_tax:IC_taxpart:IC_taxservice','');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('2352','PVN ieemtais 18%','A','L','AR_tax:IC_taxpart:IC_taxservice','');
 --
 INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart where accno = '2352'),'0.18','');
 INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart where accno = '2354'),'0.18','');
