@@ -105,11 +105,11 @@ insert into chart (accno,description,charttype,gifi_accno,category,link) values
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2650', 'Forsikringstrekk', 'A','', 'L', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2660', 'Fagforeningstrekk', 'A','', 'L', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2690', 'Andre trekk', 'A','', 'L', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2710', 'Utgende 24% mva', 'A','', 'L', 'AR_tax:IC_taxpart:IC_taxservice:CT_tax');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2715', 'Utgende 12% mva', 'A','', 'L', 'AR_tax:IC_taxpart:IC_taxservice:CT_tax');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2710', 'Utgende 24% mva', 'A','', 'L', 'AR_tax:IC_taxpart:IC_taxservice');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2715', 'Utgende 12% mva', 'A','', 'L', 'AR_tax:IC_taxpart:IC_taxservice');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2717', 'Beregnet avgift utlandet', 'A','', 'L', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2720', 'Inngende 24% mva', 'A','', 'L', 'AP_tax:IC_taxpart:IC_taxservice:CT_tax');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2725', 'Inngende 12% mva', 'A','', 'L', 'AP_tax:IC_taxpart:IC_taxservice:CT_tax');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2720', 'Inngende 24% mva', 'A','', 'L', 'AP_tax:IC_taxpart:IC_taxservice');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2725', 'Inngende 12% mva', 'A','', 'L', 'AP_tax:IC_taxpart:IC_taxservice');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2745', 'Grunnlag 1 tjenester utlandet', 'A','', 'L', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2746', 'Grunnlag 2 tjenester utlandet', 'A','', 'L', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2750', 'Oppgjrskonto merverdiavgift', 'A','', 'L', '');
