@@ -5,19 +5,19 @@ create index acc_trans_source_key on acc_trans (lower(source));
 --
 create index ap_id_key on ap (id);
 create index ap_transdate_key on ap (transdate);
-create index ap_invnumber_key on ap (lower(invnumber));
-create index ap_ordnumber_key on ap (lower(ordnumber));
+create index ap_invnumber_key on ap (invnumber);
+create index ap_ordnumber_key on ap (ordnumber);
 create index ap_vendor_id_key on ap (vendor_id);
 create index ap_employee_id_key on ap (employee_id);
-create index ap_quonumber_key on ap (lower(quonumber));
+create index ap_quonumber_key on ap (quonumber);
 --
 create index ar_id_key on ar (id);
 create index ar_transdate_key on ar (transdate);
-create index ar_invnumber_key on ar (lower(invnumber));
-create index ar_ordnumber_key on ar (lower(ordnumber));
+create index ar_invnumber_key on ar (invnumber);
+create index ar_ordnumber_key on ar (ordnumber);
 create index ar_customer_id_key on ar (customer_id);
 create index ar_employee_id_key on ar (employee_id);
-create index ar_quonumber_key on ar (lower(quonumber));
+create index ar_quonumber_key on ar (quonumber);
 --
 create index assembly_id_key on assembly (id);
 --
@@ -29,13 +29,13 @@ create index chart_gifi_accno_key on chart (gifi_accno);
 --
 create index customer_id_key on customer (id);
 create index customer_customernumber_key on customer (customernumber);
-create index customer_name_key on customer (name);
-create index customer_contact_key on customer (contact);
+create index customer_name_key on customer (lower(name));
+create index customer_contact_key on customer (lower(contact));
 create index customer_customer_id_key on customertax (customer_id);
 --
 create index employee_id_key on employee (id);
 create unique index employee_login_key on employee (login);
-create index employee_name_key on employee (name);
+create index employee_name_key on employee (lower(name));
 --
 create index exchangerate_ct_key on exchangerate (curr, transdate);
 --
@@ -43,7 +43,7 @@ create unique index gifi_accno_key on gifi (accno);
 --
 create index gl_id_key on gl (id);
 create index gl_transdate_key on gl (transdate);
-create index gl_reference_key on gl (lower(reference));
+create index gl_reference_key on gl (reference);
 create index gl_description_key on gl (lower(description));
 create index gl_employee_id_key on gl (employee_id);
 --
@@ -56,7 +56,7 @@ create index makemodel_model_key on makemodel (lower(model));
 --
 create index oe_id_key on oe (id);
 create index oe_transdate_key on oe (transdate);
-create index oe_ordnumber_key on oe (lower(ordnumber));
+create index oe_ordnumber_key on oe (ordnumber);
 create index oe_employee_id_key on oe (employee_id);
 create index orderitems_trans_id_key on orderitems (trans_id);
 create index orderitems_id_key on orderitems (id);
@@ -67,9 +67,9 @@ create index parts_description_key on parts (lower(description));
 create index partstax_parts_id_key on partstax (parts_id);
 --
 create index vendor_id_key on vendor (id);
-create index vendor_name_key on vendor (name);
+create index vendor_name_key on vendor (lower(name));
 create index vendor_vendornumber_key on vendor (vendornumber);
-create index vendor_contact_key on vendor (contact);
+create index vendor_contact_key on vendor (lower(contact));
 create index vendortax_vendor_id_key on vendortax (vendor_id);
 --
 create index shipto_trans_id_key on shipto (trans_id);
@@ -95,4 +95,6 @@ create index audittrail_trans_id_key on audittrail (trans_id);
 create index translation_trans_id_key on translation (trans_id);
 --
 create unique index language_code_key on language (code);
+--
+create index jcitems_id_key on jcitems (id);
 
