@@ -114,13 +114,13 @@ insert into chart (accno,description,charttype,gifi_accno,category,link) values
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223000000','Rozrachunki publicznoprawne','A','','L','AP');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223010000','Rozrachunki z urzdem skarbowym z tytuu VAT','A','','L','AP_amount');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223020000','Rozliczenie nalenego VAT','A','','L','AP');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223020100','Rozliczenie nalenego VAT-22%','A','','L','AR_tax:IC_taxpart:IC_taxservice:CT_tax');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223020200','Rozliczenie nalenego VAT-7%','A','','L','AR_tax:IC_taxpart:IC_taxservice:CT_tax');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223020300','Rozliczenie nalenego VAT-0%','A','','L','AR_tax:IC_taxpart:IC_taxservice:CT_tax');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223020100','Rozliczenie nalenego VAT-22%','A','','L','AR_tax:IC_taxpart:IC_taxservice');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223020200','Rozliczenie nalenego VAT-7%','A','','L','AR_tax:IC_taxpart:IC_taxservice');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223020300','Rozliczenie nalenego VAT-0%','A','','L','AR_tax:IC_taxpart:IC_taxservice');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223030000','Rozliczenie naliczonego VAT','A','','L','AP');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223030100','Rozliczenie naliczonego VAT-22%','A','','L','AP_tax:IC_taxpart:IC_taxservice:CT_tax');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223030200','Rozliczenie naliczonego VAT-7%','A','','L','AP_tax:IC_taxpart:IC_taxservice:CT_tax');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223030300','Rozliczenie naliczonego VAT-0%','A','','L','AP_tax:IC_taxpart:IC_taxservice:CT_tax');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223030100','Rozliczenie naliczonego VAT-22%','A','','L','AP_tax:IC_taxpart:IC_taxservice');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223030200','Rozliczenie naliczonego VAT-7%','A','','L','AP_tax:IC_taxpart:IC_taxservice');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223030300','Rozliczenie naliczonego VAT-0%','A','','L','AP_tax:IC_taxpart:IC_taxservice');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223040000','Korekty naliczonego VAT','A','','L','AP_paid');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223050000','Rozrachunki z Urzdem Celnym','A','','L','AP_paid');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('223060000','Rozrachunki z Urzdem Skarbowym z tytuu znakw akcyzy','A','','L','AP_amount');
